==> VL_Theme-0.1-i586.tar.xz: install/doinst.sh <==
#!/bin/bash

( cd etc/bootsplash/themes ; rm -rf current )
( cd etc/bootsplash/themes ; ln -sf VL-Clipse/ current )
( cd boot/bitmap ; rm -rf boot.bmp )
( cd boot/bitmap ; ln -sf VL-Clipse.bmp boot.bmp )
echo "Enjoy The Theme"

( cd usr/share/icons/Faenza/apps/16 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/16 ; ln -sf /usr/share/icons/Faenza/mimetypes/16/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/22 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/22 ; ln -sf /usr/share/icons/Faenza/mimetypes/22/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/24 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/24 ; ln -sf /usr/share/icons/Faenza/mimetypes/24/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/32 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/32 ; ln -sf /usr/share/icons/Faenza/mimetypes/32/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/48 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/48 ; ln -sf /usr/share/icons/Faenza/mimetypes/48/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/scalable ; rm -rf epdfview.svg )
( cd usr/share/icons/Faenza/apps/scalable ; ln -sf /usr/share/icons/Faenza/mimetypes/scalable/pdf.svg epdfview.svg )
( cd usr/share/icons/Faenza/categories/16 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/16 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/22 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/22 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/24 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/24 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/32 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/32 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/48 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/48 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/scalable ; rm -rf multimedia-volume-control.svg )
( cd usr/share/icons/Faenza/categories/scalable ; ln -sf /usr/share/icons/Faenza/categories/scalable/preferences-desktop.svg multimedia-volume-control.svg )

==> VL_Theme-0.2-i586.tar.xz: install/doinst.sh <==
#!/bin/bash

( cd etc/bootsplash/themes ; rm -rf current )
( cd etc/bootsplash/themes ; ln -sf vl71/ current )
( cd boot/bitmap ; rm -rf boot.bmp )
( cd boot/bitmap ; ln -sf VL-Rayz.bmp boot.bmp )
echo "Enjoy The Theme"

( cd usr/share/icons/Faenza/apps/16 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/16 ; ln -sf /usr/share/icons/Faenza/mimetypes/16/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/22 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/22 ; ln -sf /usr/share/icons/Faenza/mimetypes/22/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/24 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/24 ; ln -sf /usr/share/icons/Faenza/mimetypes/24/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/32 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/32 ; ln -sf /usr/share/icons/Faenza/mimetypes/32/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/48 ; rm -rf epdfview.png )
( cd usr/share/icons/Faenza/apps/48 ; ln -sf /usr/share/icons/Faenza/mimetypes/48/pdf.png epdfview.png )
( cd usr/share/icons/Faenza/apps/scalable ; rm -rf epdfview.svg )
( cd usr/share/icons/Faenza/apps/scalable ; ln -sf /usr/share/icons/Faenza/mimetypes/scalable/pdf.svg epdfview.svg )
( cd usr/share/icons/Faenza/categories/16 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/16 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/22 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/22 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/24 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/24 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/32 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/32 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/48 ; rm -rf multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/48 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
( cd usr/share/icons/Faenza/categories/scalable ; rm -rf multimedia-volume-control.svg )
( cd usr/share/icons/Faenza/categories/scalable ; ln -sf /usr/share/icons/Faenza/categories/scalable/preferences-desktop.svg multimedia-volume-control.svg )
